@@ -1,5 +1,5 @@
 import json
-from typing import Optional
+from typing import Dict, List, Optional
 import html
 import boto3
 from pythonit_toolkit.emails.templates import EmailTemplate
@@ -19,14 +19,18 @@ class SESEmailBackend(EmailBackend):
         subject: str,
         from_: str,
         to: str,
-        variables: Optional[dict[str, str]] = None,
+        variables: Optional[Dict[str, str]] = None,
+        reply_to: List[str] = None,
     ):
+        reply_to = reply_to or []
+
         variables = self.encode_vars({"subject": subject, **(variables or {})})
         self.ses.send_templated_email(
             Source=from_,
             Destination={"ToAddresses": [to]},
             Template=f"pythonit-{self.environment}-{template}",
             TemplateData=json.dumps(variables),
+            ReplyToAddresses=reply_to,
         )
 
     def encode_vars(self, variables: dict[str, str]) -> dict[str, str]:
